@@ -319,7 +319,22 @@ batchdownloader::batchdownloader( const Context& ctx ) :
 
 void batchdownloader::keyPressed( utility::mainWindowKeyCombo m )
 {
-	utility::keyPressed( m_table,m ) ;
+	if( m == utility::mainWindowKeyCombo::ENTER ){
+
+		auto m = m_ui.lineEditBDUrl->text() ;
+
+		if( !m.isEmpty() ){
+
+			this->addToList( m,{ false,false } ) ;
+		}
+
+		if( m_ui.pbBDDownload->isEnabled() ){
+
+			m_ui.pbBDDownload->click() ;
+		}
+	}else{
+		utility::keyPressed( m_table,m ) ;
+	}
 }
 
 void batchdownloader::showCustomContext()
@@ -2032,10 +2047,11 @@ void batchdownloader::showThumbnail( const engines::engine& engine,
 
 	args.append( m_table.url( index ) ) ;
 
-	auto ctx = utility::make_ctx( events( *this,engine,index,url,wrapper ),
-				     wrapper,
-				     m_terminator.setUp(),
-				     QProcess::ProcessChannel::StandardOutput ) ;
+	auto ctx = utility::make_ctx( m_ctx,
+				      events( *this,engine,index,url,wrapper ),
+				      wrapper,
+				      m_terminator.setUp(),
+				      QProcess::ProcessChannel::StandardOutput ) ;
 
 	utility::run( args,QString(),ctx.move() ) ;
 }
@@ -2575,7 +2591,7 @@ void batchdownloader::showList( batchdownloader::listType listType,
 
 	events ev( *this,listType,engine,row ) ;
 
-	auto ctx = utility::make_ctx( ev.move(),logger.move(),term.move(),ch ) ;
+	auto ctx = utility::make_ctx( m_ctx,ev.move(),logger.move(),term.move(),ch ) ;
 
 	utility::run( args,QString(),ctx.move() ) ;
 }
@@ -2971,12 +2987,8 @@ void batchdownloader::downloadRecursively( const engines::engine& eng,int index
 		int m_index ;
 	} ;
 
-	auto m = m_ui.lineEditBDUrlOptions->text() ;
-
 	const auto& engine = utility::resolveEngine( m_table,eng,m_ctx.Engines(),index ) ;
 
-	m_settings.addOptionsHistory( engine.name(),m,settings::tabName::batch ) ;
-
 	this->downloadEvent( meaw( *this,engine,index ),engine,index,true ) ;
 }
 
