@@ -28,6 +28,8 @@
 #include "engines/wget.h"
 #include "engines/svtplay-dl.h"
 #include "engines/you-get.h"
+#include "engines/deno.h"
+#include "engines/getsauce.h"
 
 #include "reportFinished.h"
 #include "utility.h"
@@ -43,18 +45,18 @@
 #include <QNetworkProxyFactory>
 #include <QDir>
 
-static QStringList _dirEntries( const QString& e )
+QStringList engines::dirEntries( const QString& e ) const
 {
 	auto filters = QDir::Filter::Dirs | QDir::Filter::NoDotAndDotDot ;
 
 	return QDir( e ).entryList( filters ) ;
 }
 
-static QProcessEnvironment _getEnvPaths( const engines::enginePaths& paths,settings& settings )
+QProcessEnvironment engines::getEnvPaths() const
 {
 	auto env = QProcessEnvironment::systemEnvironment() ;
 
-	const auto& basePath = paths.binPath() ;
+	const auto& basePath = m_enginePaths.binPath() ;
 
 	auto separator = [ & ](){
 
@@ -68,15 +70,15 @@ static QProcessEnvironment _getEnvPaths( const engines::enginePaths& paths,setti
 
 	QString s ;
 
-	const auto l = _dirEntries( basePath ) ;
+	const auto l = this->dirEntries( basePath ) ;
 
 	if( utility::platformIsWindows() ){
 
-		const auto& mm = settings.windowsOnly3rdPartyBinPath() ;
+		const auto& mm = m_settings.windowsOnly3rdPartyBinPath() ;
 
 		s = mm ;
 
-		auto m = _dirEntries( mm ) ;
+		auto m = this->dirEntries( mm ) ;
 
 		m.removeOne( "aria2-1.36.0-win-32bit-build1" ) ;
 		m.removeOne( "aria2-1.37.0-win-32bit-build1" ) ;
@@ -143,7 +145,7 @@ engines::engines( Logger& l,const engines::enginePaths& paths,settings& s,int id
 	m_logger( l ),
 	m_settings( s ),
 	m_enginePaths( paths ),
-	m_processEnvironment( _getEnvPaths( m_enginePaths,m_settings ) ),
+	m_processEnvironment( this->getEnvPaths() ),
 	m_defaultEngine( l,m_enginePaths )
 {
 	this->updateEngines( true,id ) ;
@@ -253,14 +255,11 @@ const QString& engines::defaultEngineName() const
 	return m_defaultEngine.name() ;
 }
 
-static util::result< engines::engine > _get_engine_by_path( const QString& e,
-							    const engines& engines,
-							    Logger& logger,
-							    const engines::enginePaths& enginePaths )
+util::result< engines::engine > engines::getEngineByPath( const QString& e ) const
 {
-	auto path = enginePaths.enginePath( e ) ;
+	auto path = m_enginePaths.enginePath( e ) ;
 
-	util::Json json( engines::file( path,logger ).readAll() ) ;
+	util::Json json( engines::file( path,m_logger ).readAll() ) ;
 
 	if( json ){
 
@@ -279,13 +278,13 @@ static util::result< engines::engine > _get_engine_by_path( const QString& e,
 
 				auto m = QObject::tr( "Engine \"%1\" requires atleast version \"%2\" of Media Downloader" ) ;
 
-				logger.add( m.arg( name,minVersion ),utility::sequentialID() ) ;
+				m_logger.add( m.arg( name,minVersion ),utility::sequentialID() ) ;
 
 				return {} ;
 			}
 		}
 
-		return { logger,enginePaths,object,engines,utility::sequentialID() } ;
+		return { m_logger,m_enginePaths,object,*this,utility::sequentialID() } ;
 	}else{
 		return {} ;
 	}
@@ -343,46 +342,48 @@ void engines::setDefaultEngine( const QString& name )
 	}
 }
 
+void engines::engineAdd( const QString& jsonFile,util::result< engines::engine > m,int id )
+{
+	if( m ){
+
+		if( m->exePath().isEmpty() ){
+
+			auto s = QObject::tr( "Error, executable to backend \"%1\" could not be found" ) ;
+
+			m_logger.add( s.arg( m->name() ),id ) ;
+		}else{
+			m_backends.emplace_back( std::move( m.value() ) ) ;
+		}
+	}else{
+		m_logger.add( QObject::tr( "Error, failed to parse config file \"%1\"" ).arg( jsonFile ),id ) ;
+	}
+}
+
 void engines::updateEngines( bool addAll,int id )
 {
 	m_backends.clear() ;
 
-	auto _engine_add = [ & ]( const QString& jsonFile,util::result< engines::engine > m ){
-
-		if( m ){
-
-			if( m->exePath().isEmpty() ){
-
-				m_logger.add( QObject::tr( "Error, executable to backend \"%1\" could not be found" ).arg( m->name() ),id ) ;
-			}else{
-				m_backends.emplace_back( std::move( m.value() ) ) ;
-			}
-		}else{
-			m_logger.add( QObject::tr( "Error, failed to parse config file \"%1\"" ).arg( jsonFile ),id ) ;
-		}
-	} ;
-
-	_engine_add( "",_get_engine_by_path( m_defaultEngine.configFileName(),*this,m_logger,m_enginePaths ) ) ;
+	this->engineAdd( "",this->getEngineByPath( m_defaultEngine.configFileName() ),id ) ;
 
 	const auto mm = this->enginesList() ;
 
 	for( const auto& it : mm ){
 
-		_engine_add( it,_get_engine_by_path( it,*this,m_logger,m_enginePaths ) ) ;
+		this->engineAdd( it,this->getEngineByPath( it ),id ) ;
 	}
 
 	if( addAll ){
 
 		if( utility::platformIsWindows() ){
 
-			_engine_add( "",{ *this,m_logger,"bsdtar","--version",0,1,id } ) ;
+			this->engineAdd( "",{ *this,m_logger,"bsdtar","--version",0,1,id },id ) ;
 		}else{
 			auto m = utility::platformIsLinux() ? 3 : 1 ;
 
-			_engine_add( "",{ *this,m_logger,"tar","--version",0,m,id } ) ;
+			this->engineAdd( "",{ *this,m_logger,"tar","--version",0,m,id },id ) ;
 		}
 
-		_engine_add( "",{ *this,m_logger,"ffmpeg","-version",0,2,id } ) ;
+		this->engineAdd( "",{ *this,m_logger,"ffmpeg","-version",0,2,id },id ) ;
 
 		for( const auto& it : this->getEngines() ){
 
@@ -392,9 +393,9 @@ void engines::updateEngines( bool addAll,int id )
 
 				if( utility::platformIsWindows() ){
 
-					_engine_add( it.name(),{ *this,m_logger,"python","--version",0,1,id } ) ;
+					this->engineAdd( it.name(),{ *this,m_logger,"python","--version",0,1,id },id ) ;
 				}else{
-					_engine_add( it.name(),{ *this,m_logger,"python3","--version",0,1,id } ) ;
+					this->engineAdd( it.name(),{ *this,m_logger,"python3","--version",0,1,id },id ) ;
 				}
 				break ;
 			}
@@ -439,6 +440,14 @@ void engines::updateEngines( bool addAll,int id )
 
 			it.setBackend< wget >( engines ) ;
 
+		}else if( name.contains( "deno" ) ){
+
+			it.setBackend< deno >( engines ) ;
+
+		}else if( name.contains( "getsauce" ) ){
+
+			it.setBackend< getsauce >( engines,m_settings.downloadFolder() ) ;
+
 		}else if( it.mainEngine() ){
 
 			it.setBackend< generic >( engines ) ;
@@ -495,27 +504,6 @@ const engines::enginePaths& engines::engineDirPaths() const
 	return m_enginePaths ;
 }
 
-static QStringList _toStringList( const QJsonValue& value,bool protectSpace = false ){
-
-	QStringList m ;
-
-	const auto array = value.toArray() ;
-
-	for( const auto& it : array ){
-
-		auto s = it.toString() ;
-
-		if( s.contains( ' ' ) && protectSpace ){
-
-			m.append( "\"" + s + "\"" ) ;
-		}else{
-			m.append( s ) ;
-		}
-	}
-
-	return m ;
-}
-
 settings& engines::Settings() const
 {
 	return m_settings ;
@@ -526,7 +514,7 @@ bool engines::filePathIsValid( const QFileInfo& info )
 	return info.exists() && info.isFile() ;
 }
 
-static QString _findExecutable( const QString& exeName,const QStringList& paths,QFileInfo& info )
+QString engines::findExecutable( const QString& exeName,const QStringList& paths,QFileInfo& info ) const
 {
 	for( const auto& it : paths ){
 
@@ -561,18 +549,18 @@ QString engines::findExecutable( const QString& exeName ) const
 
 		auto paths = this->processEnvironment().value( "PATH" ).split( ';' ) ;
 		
-		auto m = _findExecutable( exeName,paths,info ) ;
+		auto m = this->findExecutable( exeName,paths,info ) ;
 
 		if( m.isEmpty() && !exeName.endsWith( ".exe" ) ){
 
-			m = _findExecutable( exeName + ".exe",paths,info ) ;
+			m = this->findExecutable( exeName + ".exe",paths,info ) ;
 		}
 
 		return m ;
 	}else{
 		auto paths = this->processEnvironment().value( "PATH" ).split( ':' ) ;
 		
-		return _findExecutable( exeName,paths,info ) ;
+		return this->findExecutable( exeName,paths,info ) ;
 	}
 }
 
@@ -629,11 +617,11 @@ QString engines::addEngine( const QByteArray& data,const QString& path,int id )
 
 void engines::removeEngine( const QString& e,int id )
 {
-	const auto& engine = _get_engine_by_path( e,*this,m_logger,m_enginePaths ) ;
+	const auto& engine = this->getEngineByPath( e ) ;
 
 	if( engine && engine->valid() ){
 
-		QFile::remove( m_enginePaths.enginePath( e ) ) ;
+		utility::removeFile( m_enginePaths.enginePath( e ) ) ;
 
 		if( engine->archiveContainsFolder() ){
 
@@ -641,7 +629,7 @@ void engines::removeEngine( const QString& e,int id )
 
 			if( m.exists() && m.isDir() ){
 
-				QDir( m.filePath() ).removeRecursively() ;
+				utility::removeFolder( m.filePath() ) ;
 			}
 		}else{
 			auto exe = QDir::fromNativeSeparators( engine->exePath().realExe() ) ;
@@ -649,7 +637,7 @@ void engines::removeEngine( const QString& e,int id )
 
 			if( exe.startsWith( binPath ) && QFile::exists( exe ) ){
 
-				QFile::remove( exe ) ;
+				utility::removeFile( exe ) ;
 			}
 		}
 
@@ -711,8 +699,36 @@ engines::engine::engine( const engines& engines,
 	}
 }
 
+QStringList engines::engine::toStringList( const QJsonValue& value,bool protectSpace ) const
+{
+	QStringList m ;
+
+	const auto array = value.toArray() ;
+
+	for( const auto& it : array ){
+
+		auto s = it.toString() ;
+
+		if( s.contains( ' ' ) && protectSpace ){
+
+			m.append( "\"" + s + "\"" ) ;
+		}else{
+			m.append( s ) ;
+		}
+	}
+
+	return m ;
+}
+
 void engines::engine::updateOptions()
 {
+	auto m = this->toStringList( m_jsonObject.value( "ExtraArguments" ) ) ;
+
+	if( m.size() && m.last() != "ejs:github" ){
+
+		m_extraArguments = m ;
+	}
+
 	m_controlStructure                = m_jsonObject.value( "ControlJsonStructure" ).toObject() ;
 	m_canDownloadPlaylist             = m_jsonObject.value( "CanDownloadPlaylist" ).toBool() ;
 	m_replaceOutputWithProgressReport = m_jsonObject.value( "ReplaceOutputWithProgressReport" ).toBool( false ) ;
@@ -724,18 +740,18 @@ void engines::engine::updateOptions()
 	m_cookieArgument                  = m_jsonObject.value( "CookieArgument" ).toString() ;
 	m_cookieTextFileArgument          = m_jsonObject.value( "CookieArgumentTextFile" ).toString() ;
 	m_encodingArgument                = m_jsonObject.value( "EncodingArgument" ).toString() ;
-	m_dumpJsonArguments               = _toStringList( m_jsonObject.value( "DumptJsonArguments" ) ) ;
-	m_splitLinesBy                    = _toStringList( m_jsonObject.value( "SplitLinesBy" ) ) ;
-	m_removeText                      = _toStringList( m_jsonObject.value( "RemoveText" ) ) ;
-	m_skiptLineWithText               = _toStringList( m_jsonObject.value( "SkipLineWithText" ) ) ;
-	m_defaultDownLoadCmdOptions       = _toStringList( m_jsonObject.value( "DefaultDownLoadCmdOptions" ),true ) ;
-	m_defaultListCmdOptions           = _toStringList( m_jsonObject.value( "DefaultListCmdOptions" ) ) ;
-	m_defaultCommentsCmdOptions       = _toStringList( m_jsonObject.value( "DefaultCommentsCmdOptions" ) ) ;
-	m_defaultSubstitlesCmdOptions     = _toStringList( m_jsonObject.value( "DefaultSubstitlesCmdOptions" ) ) ;
-	m_defaultSubtitleDownloadOptions  = _toStringList( m_jsonObject.value( "DefaultSubtitleDownloadOptions" ) ) ;
+	m_dumpJsonArguments               = this->toStringList( m_jsonObject.value( "DumptJsonArguments" ) ) ;
+	m_splitLinesBy                    = this->toStringList( m_jsonObject.value( "SplitLinesBy" ) ) ;
+	m_removeText                      = this->toStringList( m_jsonObject.value( "RemoveText" ) ) ;
+	m_skiptLineWithText               = this->toStringList( m_jsonObject.value( "SkipLineWithText" ) ) ;
+	m_defaultDownLoadCmdOptions       = this->toStringList( m_jsonObject.value( "DefaultDownLoadCmdOptions" ),true ) ;
+	m_defaultListCmdOptions           = this->toStringList( m_jsonObject.value( "DefaultListCmdOptions" ) ) ;
+	m_defaultCommentsCmdOptions       = this->toStringList( m_jsonObject.value( "DefaultCommentsCmdOptions" ) ) ;
+	m_defaultSubstitlesCmdOptions     = this->toStringList( m_jsonObject.value( "DefaultSubstitlesCmdOptions" ) ) ;
+	m_defaultSubtitleDownloadOptions  = this->toStringList( m_jsonObject.value( "DefaultSubtitleDownloadOptions" ) ) ;
 }
 
-static QJsonObject _getCmd( const QJsonObject& cmd )
+QJsonObject engines::engine::getCmd( const QJsonObject& cmd )
 {
 	if( utility::platformIsWindows() ){
 
@@ -759,17 +775,32 @@ engines::engine::cmd engines::engine::getCommands( const QJsonObject& cmd )
 {
 	auto obj = [ & ](){
 
-		if( utility::platformIs32Bit() ){
+		utility::CPU cpu ;
 
-			return _getCmd( cmd ).value( "x86" ).toObject() ;
-		}else{
-			return _getCmd( cmd ).value( "amd64" ).toObject() ;
+		if( cpu.x86_32() ){
+
+			return this->getCmd( cmd ).value( "x86" ).toObject() ;
+
+		}else if( cpu.x86_64() ){
+
+			return this->getCmd( cmd ).value( "amd64" ).toObject() ;
+
+		}else if( cpu.aarch64() ){
+
+			auto m = this->getCmd( cmd ).value( "aarch64" ).toObject() ;
+
+			if( !m.isEmpty() ){
+
+				return m ;
+			}
 		}
+
+		return this->getCmd( cmd ).value( "amd64" ).toObject() ;
 	}() ;
 
 	auto m = obj.value( "Name" ).toString() ;
 
-	auto s = _toStringList( obj.value( "Args" ).toArray() ) ;
+	auto s = this->toStringList( obj.value( "Args" ).toArray() ) ;
 
 	return { m,s,s.size() == 1 } ;
 }
@@ -782,7 +813,7 @@ engines::engine::cmd engines::engine::getLegacyCommands()
 
 		exe = m_jsonObject.value( "CommandNameWindows" ).toString() ;
 
-		if( utility::platformIs32Bit() ){
+		if( utility::CPU().x86_32() ){
 
 			auto m = m_jsonObject.value( "CommandName32BitWindows" ).toString() ;
 
@@ -802,25 +833,25 @@ engines::engine::cmd engines::engine::getLegacyCommands()
 
 	if( utility::platformIsWindows() ){
 
-		if( utility::platformIs32Bit() ){
+		if( utility::CPU().x86_32() ){
 
-			auto m = _toStringList( m_jsonObject.value( "CommandNames32BitWindows" ) ) ;
+			auto m = this->toStringList( m_jsonObject.value( "CommandNames32BitWindows" ) ) ;
 
 			if( !m.isEmpty() ){
 
 				return { exe,m,m.isEmpty() } ;
 			}else{
-				auto s = _toStringList( m_jsonObject.value( "CommandNamesWindows" ) ) ;
+				auto s = this->toStringList( m_jsonObject.value( "CommandNamesWindows" ) ) ;
 
 				return { exe,s,s.isEmpty() } ;
 			}
 		}else{
-			auto s = _toStringList( m_jsonObject.value( "CommandNamesWindows" ) ) ;
+			auto s = this->toStringList( m_jsonObject.value( "CommandNamesWindows" ) ) ;
 
 			return { exe,s,s.isEmpty() } ;
 		}
 	}else{
-		auto s = _toStringList( m_jsonObject.value( "CommandNames" ) ) ;
+		auto s = this->toStringList( m_jsonObject.value( "CommandNames" ) ) ;
 
 		return { exe,s,s.isEmpty() } ;
 	}
@@ -840,6 +871,7 @@ engines::engine::engine( Logger& logger,
 	m_archiveContainsFolder( m_jsonObject.value( "ArchiveContainsFolder" ).toBool() ),
 	m_versionArgument( m_jsonObject.value( "VersionArgument" ).toString() ),
 	m_name( m_jsonObject.value( "Name" ).toString() ),
+	m_configVersion( m_jsonObject.value( "Version" ).toString() ),
 	m_likeYtDlp( m_name.startsWith( "yt-dlp" ) || m_name == "ytdl-patched" ),
 	m_exeFolderPath( m_jsonObject.value( "BackendPath" ).toString() ),
 	m_downloadUrl( m_jsonObject.value( "DownloadUrl" ).toString() )
@@ -881,7 +913,7 @@ engines::engine::engine( Logger& logger,
 		}else{
 			QJsonValue value ;
 
-			if( utility::platformIs32Bit() ){
+			if( utility::CPU().x86_32() ){
 
 				value = cmd.toObject().value( "Windows" ).toObject().value( "win7x86" ) ;
 			}else{
@@ -1094,6 +1126,11 @@ QString engines::engine::versionString( const QString& data ) const
 
 			m.replace( ",","" ).replace( "v","" ) ;
 
+			if( m == "N-121066-g189d0b83b2-20250915" ){
+
+				m = "n8.1-dev-121066-g189d0b83b2-20250915" ;
+			}
+
 			return m ;
 		}
 	}
@@ -1231,6 +1268,10 @@ QString engines::engine::baseEngine::errorString( const engine::engine::baseEngi
 
 		auto m = engines::engine::baseEngine::processCompleteStateText( f ) ;
 		return m + "\n" + QObject::tr( "Sign In To Confirm You Are Not A Bot" ) + "\n" + bkText ;
+
+	}else if( err == engines::engine::baseEngine::errors::runtimeError ){
+
+		return QObject::tr( "Download Failed, Engine crashed" ) + "\n" + bkText ;
 	}else{
 		return {} ;
 	}
@@ -1268,7 +1309,7 @@ QString engines::engine::baseEngine::processCompleteStateText( const engine::eng
 	}
 }
 
-static bool _meetExtraCondition( const QByteArray& l,const QJsonObject& obj )
+bool engines::engine::baseEngine::meetExtraCondition( const QByteArray& l,const QJsonObject& obj )
 {
 	const QString line = l ;
 
@@ -1332,7 +1373,7 @@ bool engines::engine::baseEngine::meetCondition( const engines::engine& engine,c
 
 		if( m.isObject() ){
 
-			return _meetExtraCondition( line,m.toObject() ) ;
+			return engines::engine::baseEngine::meetExtraCondition( line,m.toObject() ) ;
 		}else{
 			return false ;
 		}
@@ -1342,8 +1383,8 @@ bool engines::engine::baseEngine::meetCondition( const engines::engine& engine,c
 
 		if( obj1.isObject() && obj2.isObject() ){
 
-			auto a = _meetExtraCondition( line,obj1.toObject() ) ;
-			auto b = _meetExtraCondition( line,obj2.toObject() ) ;
+			auto a = engines::engine::baseEngine::meetExtraCondition( line,obj1.toObject() ) ;
+			auto b = engines::engine::baseEngine::meetExtraCondition( line,obj2.toObject() ) ;
 
 			if( connector == "&&" ){
 
@@ -1400,35 +1441,21 @@ const QProcessEnvironment& engines::engine::baseEngine::processEnvironment() con
 
 engines::metadata engines::engine::baseEngine::parseJsonDataFromGitHub( const QJsonDocument& doc )
 {
-	engines::metadata metadata ;
-
-	auto object = doc.object() ;
-
-	auto value = object.value( "assets" ) ;
-
-	const auto array = value.toArray() ;
-
-	for( const auto& it : array ){
-
-		const auto object = it.toObject() ;
-
-		const auto value = object.value( "name" ) ;
-
-		auto entry = value.toString() ;
-
-		if( this->foundNetworkUrl( entry ) ){
-
-			metadata.url = object.value( "browser_download_url" ).toString() ;
-
-			metadata.size = object.value( "size" ).toInt() ;
-
-			metadata.fileName = entry ;
-
-			break ;
+	class meaw
+	{
+	public:
+		meaw( engines::engine::baseEngine& parent ) : m_parent( parent )
+		{
 		}
-	}
+		bool operator()( const QJsonObject& obj )
+		{
+			return m_parent.foundNetworkUrl( obj.value( "name" ).toString() ) ;
+		}
+	private:
+		engines::engine::baseEngine& m_parent ;
+	} ;
 
-	return metadata ;
+	return utility::parseJsonDataFromGitHub( doc,meaw( *this ) ) ;
 }
 
 std::vector< engines::engine::baseEngine::mediaInfo > engines::engine::baseEngine::mediaProperties( Logger&,const QByteArray& e )
@@ -1498,6 +1525,16 @@ bool engines::engine::baseEngine::updateVersionInfo()
 	return false ;
 }
 
+bool engines::engine::baseEngine::supportingEngine()
+{
+	return false ;
+}
+
+QByteArray engines::engine::baseEngine::parseError( const QByteArray& )
+{
+	return {} ;
+}
+
 void engines::engine::baseEngine::setTextEncondig( const QString&,QStringList& )
 {
 }
@@ -1576,8 +1613,9 @@ void engines::engine::baseEngine::updateLocalOptions( QStringList& )
 {
 }
 
-void engines::engine::baseEngine::setProxySetting( QStringList&,const QString& )
+engines::engine::baseEngine::optionsEnvironment engines::engine::baseEngine::setProxySetting( QStringList&,const QString& )
 {
+	return {} ;
 }
 
 QString engines::engine::baseEngine::setCredentials( QStringList&,QStringList& )
@@ -1659,9 +1697,10 @@ bool engines::engine::baseEngine::foundNetworkUrl( const QString& s )
 	return s == m_engine.commandName() ;
 }
 
-bool engines::engine::baseEngine::renameArchiveFolder( const QString&,const QString& )
+engines::engine::baseEngine::renameArchiveFolderStatus
+engines::engine::baseEngine::renameArchiveFolder( const QString&,const QString& )
 {
-	return false ;
+	return {} ;
 }
 
 QString engines::engine::baseEngine::updateTextOnCompleteDownlod( const QString& uiText,
@@ -1953,7 +1992,8 @@ void engines::engine::baseEngine::processData( Logger::Data& outPut,
 }
 
 void engines::engine::baseEngine::updateDownLoadCmdOptions( const engines::engine::baseEngine::updateOpts& s,
-							    bool downloadOptionsAsLast )
+							    bool downloadOptionsAsLast,
+							    const QStringList& extraOpts )
 {
 	if( downloadOptionsAsLast ){
 
@@ -1971,6 +2011,8 @@ void engines::engine::baseEngine::updateDownLoadCmdOptions( const engines::engin
 			s.ourOptions.append( s.uiOptions ) ;
 		}
 	}
+
+	s.ourOptions.append( extraOpts ) ;
 }
 
 void engines::engine::baseEngine::updateGetPlaylistCmdOptions( QStringList& )
@@ -2298,6 +2340,7 @@ engines::configDefaultEngine::configDefaultEngine( Logger&logger,const enginePat
 	m_configFileName( m_name + ".json" )
 {
 	yt_dlp::init( this->name(),this->configFileName(),logger,enginePath ) ;
+	deno::init( "deno","deno.json",logger,enginePath ) ;
 
 	if( utility::platformIsWindows() ){
 
@@ -2421,3 +2464,15 @@ QString engines::proxySettings::toString( const QNetworkProxy& e ) const
 		return type + credentials + host ;
 	}
 }
+
+QProcessEnvironment engines::engine::baseEngine::optionsEnvironment::update( const QProcessEnvironment& e ) const
+{
+	auto m = e ;
+
+	for( const auto& it : m_pairs ){
+
+		m.insert( it.key,it.value ) ;
+	}
+
+	return m ;
+}
