@@ -251,15 +251,44 @@ public:
 		QString m_tmp ;
 	} ;
 
-	struct metadata
+	class metadata
 	{
-		qint64 size = 0 ;
-		QString url ;
-		QString fileName ;
+	public:
+		metadata( const QJsonObject& obj ) :
+			m_url( obj.value( "browser_download_url" ).toString() ),
+			m_size( obj.value( "size" ).toInt() ),
+			m_fileName( obj.value( "name" ).toString() ),
+			m_hash( obj.value( "digest" ).toString() )
+		{
+		}
+		metadata()
+		{
+		}
 		metadata move()
 		{
 			return std::move( *this ) ;
 		}
+		const QString& url() const
+		{
+			return m_url ;
+		}
+		const QString& fileName() const
+		{
+			return m_fileName ;
+		}
+		const QString& hash() const
+		{
+			return m_hash ;
+		}
+		qint64 size() const
+		{
+			return m_size ;
+		}
+	private:
+		QString m_url ;
+		qint64 m_size = 0 ;
+		QString m_fileName ;
+		QString m_hash ;
 	} ;
 
 	class engine
@@ -389,7 +418,7 @@ public:
 				engines::ProcessExitState::ExitStatus m_exitStatus ;
 			};
 
-			enum class errors{ unknownUrl,notSupportedUrl,noNetwork,unknownFormat,logInRequired } ;
+			enum class errors{ runtimeError,unknownUrl,notSupportedUrl,noNetwork,unknownFormat,logInRequired } ;
 			static QString errorString( const engine::engine::baseEngine::finishedState&,
 						    engines::engine::baseEngine::errors,
 						    const QString& ) ;
@@ -705,6 +734,10 @@ public:
 
 			virtual bool updateVersionInfo() ;
 
+			virtual bool supportingEngine() ;
+
+			virtual QByteArray parseError( const QByteArray& ) ;
+
 			virtual void setTextEncondig( const QString&,QStringList& opts ) ;
 
 			virtual QJsonObject parseJson( const QString&,const QByteArray& ) ;
@@ -727,7 +760,38 @@ public:
 
 			virtual void updateLocalOptions( QStringList& ) ;
 
-			virtual void setProxySetting( QStringList&,const QString& ) ;
+			class optionsEnvironment
+			{
+			public:
+				optionsEnvironment()
+				{
+				}
+				optionsEnvironment( QString key,QString value )
+				{
+					m_pairs.emplace_back( std::move( key ),std::move( value ) ) ;
+				}
+				void add( QString key,QString value )
+				{
+					m_pairs.emplace_back( std::move( key ),std::move( value ) ) ;
+				}
+				bool isEmpty() const
+				{
+					return m_pairs.size() ;
+				}
+				QProcessEnvironment update( const QProcessEnvironment& ) const ;
+			private:
+				struct pair
+				{
+					pair( QString k,QString v ) :
+						key( std::move( k ) ),value( std::move( v ) )
+					{
+					}
+					QString key ;
+					QString value ;
+				} ;
+				std::vector< pair > m_pairs ;
+			} ;
+			virtual optionsEnvironment setProxySetting( QStringList&,const QString& ) ;
 
 			virtual QString setCredentials( QStringList&,QStringList & ) ;
 
@@ -758,7 +822,38 @@ public:
 
 			virtual bool foundNetworkUrl( const QString& ) ;
 
-			virtual bool renameArchiveFolder( const QString&,const QString& ) ;
+			class renameArchiveFolderStatus
+			{
+			public:
+				renameArchiveFolderStatus( const QString& s,const QString& d,const QString& e ) :
+					m_src( s ),m_dst( d ),m_err( e )
+				{
+				}
+				renameArchiveFolderStatus()
+				{
+				}
+				const QString& src() const
+				{
+					return m_src ;
+				}
+				const QString& dst() const
+				{
+					return m_dst ;
+				}
+				const QString& err() const
+				{
+					return m_err ;
+				}
+				bool success() const
+				{
+					return m_err.isEmpty() ;
+				}
+			private:
+				QString m_src ;
+				QString m_dst ;
+				QString m_err ;
+			} ;
+			virtual renameArchiveFolderStatus renameArchiveFolder( const QString&,const QString& ) ;
 
 			QString updateTextOnCompleteDownlod( const QString& uiText,
 							     const QString& downloadingOptions,
@@ -815,7 +910,9 @@ public:
 				QStringList& ourOptions ;
 			};
 
-			virtual void updateDownLoadCmdOptions( const engines::engine::baseEngine::updateOpts&,bool ) ;
+			virtual void updateDownLoadCmdOptions( const engines::engine::baseEngine::updateOpts&,
+							       bool,
+							       const QStringList& ) ;
 
 			virtual void updateGetPlaylistCmdOptions( QStringList& ) ;
 
@@ -828,6 +925,7 @@ public:
 			settings& m_settings ;
 			const engines::engine& m_engine ;
 			const QProcessEnvironment& m_processEnvironment ;
+			static bool meetExtraCondition( const QByteArray&,const QJsonObject& ) ;
 		} ;
 
 		engine()
@@ -856,7 +954,10 @@ public:
 		{
 			return m_name ;
 		}
-
+		const QString& configFileVersion() const
+		{
+			return m_configVersion ;
+		}
 		bool forTesting() const
 		{
 			return this->name().endsWith( "-test" ) ;
@@ -995,7 +1096,7 @@ public:
 		{
 			m_engine->processData( outPut,data,id,readableJson ) ;
 		}
-		bool renameArchiveFolder( const QString& s,const QString& e ) const
+		engines::engine::baseEngine::renameArchiveFolderStatus renameArchiveFolder( const QString& s,const QString& e ) const
 		{
 			return m_engine->renameArchiveFolder( s,e ) ;
 		}
@@ -1032,7 +1133,7 @@ public:
 		}
 		void updateDownLoadCmdOptions( const engines::engine::baseEngine::updateOpts& u,bool e ) const
 		{
-			m_engine->updateDownLoadCmdOptions( u,e ) ;
+			m_engine->updateDownLoadCmdOptions( u,e,this->extraArguments() ) ;
 		}
 		void sendCredentials( const QString& credentials,QProcess& exe ) const
 		{
@@ -1045,10 +1146,14 @@ public:
 		void updateGetPlaylistCmdOptions( QStringList& e ) const
 		{
 			m_engine->updateGetPlaylistCmdOptions( e ) ;
+
+			e.append( this->extraArguments() ) ;
 		}
 		void updateCmdOptions( QStringList& e ) const
 		{
 			m_engine->updateCmdOptions( e ) ;
+
+			e.append( this->extraArguments() ) ;
 		}
 		util::Json parsePlayListData( const QString& m,const QByteArray& e ) const
 		{
@@ -1082,9 +1187,9 @@ public:
 		{
 			return m_engine->downloadFolder( e ) ;
 		}
-		void setProxySetting( QStringList& e,const QString& s ) const
+		engines::engine::baseEngine::optionsEnvironment setProxySetting( QStringList& e,const QString& s ) const
 		{
-			m_engine->setProxySetting( e,s ) ;
+			return m_engine->setProxySetting( e,s ) ;
 		}
 		std::vector< QByteArray > parseJsonData( QByteArray& data ) const
 		{
@@ -1102,6 +1207,14 @@ public:
 		{
 			m_engine->openLocalFile( s ) ;
 		}
+		bool supportingEngine() const
+		{
+			return m_engine->supportingEngine() ;
+		}
+		QByteArray parseError( const QByteArray& e ) const
+		{
+			return m_engine->parseError( e ) ;
+		}
 		void updateOutPutChannel( QProcess::ProcessChannel& s ) const
 		{
 			m_engine->updateOutPutChannel( s ) ;
@@ -1174,6 +1287,10 @@ public:
 		{
 			return m_cookieArgument ;
 		}
+		const QStringList extraArguments() const
+		{
+			return m_extraArguments ;
+		}
 		const QJsonObject& controlStructure() const
 		{
 			return m_controlStructure ;
@@ -1233,8 +1350,9 @@ public:
 		}
 	private:
 		void setPermissions( const QString& ) const ;
-
 		void updateOptions() ;
+		QStringList toStringList( const QJsonValue&,bool = false ) const ;
+		QJsonObject getCmd( const QJsonObject& ) ;
 
 		struct cmd
 		{
@@ -1269,6 +1387,7 @@ public:
 		mutable bool m_broken = false ;
 		QString m_versionArgument ;
 		QString m_name ;
+		QString m_configVersion ;
 		bool m_likeYtDlp ;
 		QString m_commandName ;
 		QString m_userName ;
@@ -1282,6 +1401,7 @@ public:
 		QString m_cookieArgument ;
 		QString m_cookieTextFileArgument ;
 		QString m_encodingArgument ;
+		QStringList m_extraArguments ;
 		QStringList m_dumpJsonArguments ;
 		QStringList m_splitLinesBy ;
 		QStringList m_removeText ;
@@ -1423,6 +1543,11 @@ public:
 	void setNetworkProxy( engines::proxySettings,bool,networkAccess& ) ;
 private:
 	void updateEngines( bool,int ) ;
+	util::result< engines::engine > getEngineByPath( const QString& ) const ;
+	void engineAdd( const QString&,util::result< engines::engine >,int ) ;
+	QString findExecutable( const QString&,const QStringList&,QFileInfo& ) const ;
+	QProcessEnvironment getEnvPaths() const ;
+	QStringList dirEntries( const QString& ) const ;
 	Logger& m_logger ;
 	settings& m_settings ;
 	std::vector< engine > m_backends ;
