@@ -205,19 +205,26 @@ bool utility::platformIsWindows7()
 
 QString utility::windowsApplicationDirPath()
 {
-	std::array< char,4096 > buffer ;
+	std::array< wchar_t,4096 > buffer ;
 
-	GetModuleFileNameA( nullptr,buffer.data(),static_cast< DWORD >( buffer.size() ) ) ;
+	auto e = GetModuleFileNameW( nullptr,buffer.data(),static_cast< DWORD >( buffer.size() ) ) ;
 
-	auto m = QDir::fromNativeSeparators( buffer.data() ) ;
-	auto s = m.lastIndexOf( '/' ) ;
+	if( e > 0 ){
 
-	if( s != -1 ){
+		auto a = QString::fromWCharArray( buffer.data(),e ) ;
 
-		m.truncate( s ) ;
+		auto m = QDir::fromNativeSeparators( a ) ;
+		auto s = m.lastIndexOf( '/' ) ;
+
+		if( s != -1 ){
+
+			m.truncate( s ) ;
+		}
+
+		return m ;
+	}else{
+		return {} ;
 	}
-
-	return m ;
 }
 
 class adaptorInfo
@@ -650,7 +657,7 @@ void utility::checkPermissions::disable()
 
 #endif
 
-QString windowsGetLastErrorMessage()
+QString utility::errorMessage()
 {
 	char * s = nullptr ;
 
@@ -672,10 +679,10 @@ QString windowsGetLastErrorMessage()
 	return m ;
 }
 
-class renameFile
+class fileRename
 {
 public:
-	renameFile( const QString& oldPath,const QString& newPath ) :
+	fileRename( const QString& oldPath,const QString& newPath ) :
 		m_oldPath( this->setPath( oldPath ) ),m_newPath( this->setPath( newPath ) )
 	{
 	}
@@ -688,7 +695,7 @@ public:
 	}
 	QString errorString() const
 	{
-		return windowsGetLastErrorMessage() ;
+		return utility::errorMessage() ;
 	}
 	const QString& oldPath() const
 	{
@@ -707,11 +714,60 @@ private:
 	QString m_newPath ;
 } ;
 
+class fileRemove
+{
+public:
+	fileRemove( const QString& s ) : m_src( s )
+	{
+	}
+	bool exec() const
+	{
+		if( QFile::exists( m_src ) ){
+
+			//return unlink( m_src.toUtf8().constData() ) == 0 ;
+			return QFile::remove( m_src ) ;
+		}else{
+			return true ;
+		}
+	}
+	QString errorString() const
+	{
+		return utility::errorMessage() ;
+	}
+private:
+	const QString& m_src ;
+} ;
+
+class dirRemove
+{
+public:
+	dirRemove( const QString& s ) : m_src( s )
+	{
+	}
+	bool exec() const
+	{
+		QDir dir( m_src ) ;
+
+		if( dir.exists() ){
+
+			return dir.removeRecursively() ;
+		}else{
+			return true ;
+		}
+	}
+	QString errorString() const
+	{
+		return utility::errorMessage() ;
+	}
+private:
+	const QString& m_src ;
+} ;
+
 #else
 
-QString windowsGetLastErrorMessage()
+QString utility::errorMessage()
 {
-	return {} ;
+	return strerror( errno ) ;
 }
 
 void utility::checkPermissions::enable()
@@ -722,10 +778,10 @@ void utility::checkPermissions::disable()
 {
 }
 
-class renameFile
+class fileRename
 {
 public:
-	renameFile( const QString& oldPath,const QString& newPath ) :
+	fileRename( const QString& oldPath,const QString& newPath ) :
 		m_oldPath( oldPath ),m_newPath( newPath )
 	{
 	}
@@ -749,8 +805,56 @@ public:
 		return m_newPath ;
 	}
 private:
-	QString m_oldPath ;
-	QString m_newPath ;
+	const QString& m_oldPath ;
+	const QString& m_newPath ;
+} ;
+
+class fileRemove
+{
+public:
+	fileRemove( const QString& s ) : m_src( s )
+	{
+	}
+	bool exec() const
+	{
+		if( QFile::exists( m_src ) ){
+
+			return QFile::remove( m_src ) ;
+		}else{
+			return true ;
+		}
+	}
+	QString errorString() const
+	{
+		return strerror( errno ) ;
+	}
+private:
+	const QString& m_src ;
+} ;
+
+class dirRemove
+{
+public:
+	dirRemove( const QString& s ) : m_src( s )
+	{
+	}
+	bool exec() const
+	{
+		QDir dir( m_src ) ;
+
+		if( dir.exists() ){
+
+			return dir.removeRecursively() ;
+		}else{
+			return true ;
+		}
+	}
+	QString errorString() const
+	{
+		return strerror( errno ) ;
+	}
+private:
+	const QString& m_src ;
 } ;
 
 std::vector< utility::PlayerOpts > utility::getMediaPlayers()
@@ -1149,13 +1253,6 @@ QStringList utility::updateOptions( const utility::updateOptionsStruct& s )
 
 	QStringList opts ;
 
-	const auto& p = s.ctx.Engines().networkProxy() ;
-
-	if( p.isSet() ){
-
-		engine.setProxySetting( opts,p.networkProxyString() ) ;
-	}
-
 	auto oopts = [ & ](){
 
 		if( dopts.hasExtraOptions ){
@@ -1590,21 +1687,6 @@ const engines::engine& utility::resolveEngine( const tableWidget& table,
 	}
 }
 
-bool utility::platformIs32Bit()
-{
-	if( _pretendPlatform.is32Bit() ){
-
-		return true ;
-	}
-
-#if QT_VERSION >= QT_VERSION_CHECK( 5,4,0 )
-	return QSysInfo::currentCpuArchitecture() != "x86_64" ;
-#else
-	//?????
-	return false ;
-#endif
-}
-
 void utility::addJsonCmd::add( const utility::addJsonCmd::entry& e )
 {
 	QJsonObject s ;
@@ -1965,12 +2047,22 @@ bool utility::runningGitVersion()
 {
 	auto m = utility::runningVersionOfMediaDownloader() ;
 
+	return utility::runningGitVersion( m ) ;
+}
+
+bool utility::runningGitVersion( const QString& m )
+{
 	return util::split( m,"." ).size() > 3 ;
 }
 
+const QString& utility::fakeRunningVersionOfMediaDownloader()
+{
+	return _runTimeVersions().instanceVersion() ;
+}
+
 QString utility::runningVersionOfMediaDownloader()
 {
-	const auto& e = _runTimeVersions().instanceVersion() ;
+	const auto& e = utility::fakeRunningVersionOfMediaDownloader() ;
 
 	if( e.isEmpty() ){
 
@@ -2132,6 +2224,13 @@ void utility::networkReply::getData( const Context& ctx,const utils::network::re
 	}
 }
 
+static bool _useFakeHash ;
+
+bool utility::cliArguments::useFakeMdHash()
+{
+	return _useFakeHash ;
+}
+
 utility::cliArguments::cliArguments( int argc,char ** argv )
 {
 	for( int i = 0 ; i < argc ; i++ ){
@@ -2139,6 +2238,8 @@ utility::cliArguments::cliArguments( int argc,char ** argv )
 		m_args.append( argv[ i ] ) ;
 	}
 
+	_useFakeHash = this->contains( "--fake-hash" ) ;
+
 	_pretendPlatform.set( m_args ) ;
 
 	if( this->runningUpdated() ){
@@ -2274,7 +2375,9 @@ utility::printOutPut::printOutPut( const utility::cliArguments& args )
 
 			m_outPutFile.setFileName( m ) ;
 
-			m_outPutFile.open( QIODevice::WriteOnly | QIODevice::Append ) ;
+			auto m = m_outPutFile.open( QIODevice::WriteOnly | QIODevice::Append ) ;
+
+			Q_UNUSED( m )
 		}
 	}
 }
@@ -2624,16 +2727,29 @@ void utility::contextMenuForDirectUrl( std::vector< UrlLinks > links,
 
 void utility::deleteTmpFiles( const QString& df,std::vector< QByteArray > files )
 {
-	utils::qthread::run( [ df,files = std::move( files ) ](){
-
-		for( const auto& it : files ){
-
-			auto m = df + "/" + it ;
-
-			QFile::remove( m + ".part" ) ;
-			QFile::remove( m ) ;
+	class meaw
+	{
+	public:
+		meaw( const QString& df,std::vector< QByteArray > files ) :
+			m_df( df ),m_files( std::move( files ) )
+		{
 		}
-	} ) ;
+		void operator()()
+		{
+			for( const auto& it : m_files ){
+
+				auto m = m_df + "/" + it ;
+
+				QFile::remove( m + ".part" ) ;
+				QFile::remove( m ) ;
+			}
+		}
+	private:
+		QString m_df ;
+		std::vector< QByteArray > m_files ;
+	} ;
+
+	utils::qthread::run( meaw( df,std::move( files ) ) ) ;
 }
 
 bool utility::Qt6Version()
@@ -2692,7 +2808,7 @@ QString utility::rename( const Context& ctx,
 
 	auto id = utility::concurrentID() ;
 
-	renameFile rename( oldPath,newPath ) ;
+	fileRename rename( oldPath,newPath ) ;
 
 	auto e = QObject::tr( "Renaming \"%1\" to \"%2\"" ) ;
 
@@ -2724,6 +2840,34 @@ QString utility::rename( const Context& ctx,
 	}
 }
 
+template< typename Type,typename ... Args >
+QString FileSystemOperation( Args&& ... args )
+{
+	Type m( std::forward< Args >( args ) ... ) ;
+
+	if( m.exec() ){
+
+		return {} ;
+	}else{
+		return m.errorString() ;
+	}
+}
+
+QString utility::rename( const QString& oldName,const QString& newName )
+{
+	return FileSystemOperation< fileRename >( oldName,newName ) ;
+}
+
+QString utility::removeFile( const QString& e )
+{
+	return FileSystemOperation< fileRemove >( e ) ;
+}
+
+QString utility::removeFolder( const QString& e )
+{
+	return FileSystemOperation< dirRemove >( e ) ;
+}
+
 bool utility::containsLinkerWarning( const QByteArray& e )
 {
 	return e.contains( "ERROR: ld.so: object" ) ;
@@ -2755,3 +2899,57 @@ bool utility::fileIsInvalidForGettingThumbnail( const QByteArray& e )
 {
 	return e.endsWith( ".mp4" ) || e.endsWith( ".webm" ) || e.endsWith( ".avi" ) ;
 }
+
+utility::CPU::CPU() : m_cpu( this->getCPU() )
+{
+}
+
+bool utility::CPU::x86_32() const
+{
+	if( _pretendPlatform.is32Bit() ){
+
+		return true ;
+	}else{
+		return m_cpu == "i386" || m_cpu == "x86_32" ;
+	}
+}
+
+bool utility::CPU::x86_64() const
+{
+	return m_cpu == "x86_64" ;
+}
+
+bool utility::CPU::aarch64() const
+{
+	return m_cpu == "arm64" || m_cpu == "aarch64";
+}
+
+bool utility::CPU::aarch32() const
+{
+	return m_cpu == "arm" || m_cpu == "aarch32" ;
+}
+
+const QString& utility::CPU::getCPU() const
+{
+#if QT_VERSION >= QT_VERSION_CHECK( 5,4,0 )
+	static QString m = QSysInfo::currentCpuArchitecture() ;
+	return m ;
+#else
+	static QString m = [](){
+
+		if( utility::platformIsLinux() ){
+
+			QFile file( "/proc/sys/kernel/arch" ) ;
+
+			if( file.open( QIODevice::ReadOnly ) ){
+
+				return file.readAll().trimmed() ;
+			}
+		}
+
+		return QByteArray() ;
+	}() ;
+
+	return m ;
+#endif
+}
