@@ -319,9 +319,7 @@
         <source>Manually Specified Proxy Configuration
 Example 1: 192.168.93.89:8080
 Exampe 2: ${gateway}:8080</source>
-        <translation>Ръчно зададена конфигурация на прокси 
-Пример 1: 192.168.93.89:8080
-Пример 2: ${gateway}:8080</translation>
+        <translation>Ръчно зададена конфигурация на прокси</translation>
     </message>
     <message>
         <source>About</source>
@@ -421,7 +419,7 @@ Exampe 2: ${gateway}:8080</source>
     </message>
     <message>
         <source>Open Extension Folder</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
 </context>
 <context>
@@ -738,10 +736,6 @@ Exampe 2: ${gateway}:8080</source>
         <source>Failed To Find &quot;bsdtar.exe&quot; Executable</source>
         <translation>Неуспешно намиране на изпълним файл &quot;bsdtar.exe&quot;</translation>
     </message>
-    <message>
-        <source>Failed To Find &quot;tar&quot; Executable</source>
-        <translation>Неуспешно намиране на изпълним файл &quot;tar&quot;</translation>
-    </message>
     <message>
         <source>Download Failed</source>
         <translation>Изтеглянето не бе успешно</translation>
@@ -778,10 +772,6 @@ Exampe 2: ${gateway}:8080</source>
         <source>Extracting archive: </source>
         <translation>Извличане на архив: </translation>
     </message>
-    <message>
-        <source>Renaming file to: </source>
-        <translation>Преименуване на файл на: </translation>
-    </message>
     <message>
         <source>Processing</source>
         <translation>Обработка</translation>
@@ -1040,34 +1030,74 @@ Exampe 2: ${gateway}:8080</source>
     </message>
     <message>
         <source>Bulgarien (Bulgaria)</source>
-        <translation type="unfinished"></translation>
+        <translation>Български (България)</translation>
     </message>
     <message>
         <source>Open Urls With %2</source>
-        <translation type="unfinished"></translation>
+        <translation>Отваряне на URL адреси с %2</translation>
     </message>
     <message>
         <source>Default Player</source>
-        <translation type="unfinished"></translation>
+        <translation>Плеер подразбиране</translation>
     </message>
     <message>
         <source>Warning, Nothing Was Downloaded</source>
-        <translation type="unfinished"></translation>
+        <translation>Внимание, нищо не е изтеглено</translation>
     </message>
     <message>
         <source>Download Cancelled, Playlist Urls Are Not Allowed In This Tab</source>
-        <translation type="unfinished"></translation>
+        <translation>Изтеглянето е отменено, URL на плейлиста не са разрешени в този раздел</translation>
     </message>
     <message>
         <source>Download Cancelled Because A Condition Was Not Met</source>
-        <translation type="unfinished"></translation>
+        <translation>Изтеглянето е отменено, защото не е изпълнено условие</translation>
     </message>
     <message>
         <source>Download Failed, Unknown Reason</source>
-        <translation type="unfinished"></translation>
+        <translation>Изтеглянето не бе успешно, причината е неизвестна</translation>
     </message>
     <message>
         <source>Download Failed, Network Issue</source>
+        <translation>Изтеглянето не бе успешно, проблем с мрежата</translation>
+    </message>
+    <message>
+        <source>Ukrainian (Ukraine)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Renaming &quot;%1&quot; to &quot;%2&quot;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Renaming Failed: %3</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Skipping Checking Download Hash</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ignoring Download Because Hashes Do Not Match</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Expected &quot;%1&quot; but obtained &quot;%2&quot;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed To Remove</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Renaming file to: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed To Find &quot;bsdtar&quot; Executable</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Skipping Checking Version Info For Engine &quot;%1&quot;</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
