@@ -739,10 +739,6 @@ Exampe 2: ${gateway}:8080</source>
         <source>Failed To Find &quot;bsdtar.exe&quot; Executable</source>
         <translation>Απέτυχε η εύρεση του εκτέλεσιμου &quot;bsdtar.exe&quot;</translation>
     </message>
-    <message>
-        <source>Failed To Find &quot;tar&quot; Executable</source>
-        <translation>Απέτυχε η εύρεση του εκτέλεσιμου &quot;tar&quot;</translation>
-    </message>
     <message>
         <source>Download Failed</source>
         <translation>Η λήψη απέτυχε</translation>
@@ -779,10 +775,6 @@ Exampe 2: ${gateway}:8080</source>
         <source>Extracting archive: </source>
         <translation>Εξαγωγή αρχειοθήκης: </translation>
     </message>
-    <message>
-        <source>Renaming file to: </source>
-        <translation>Μετονομασία αρχείου σε: </translation>
-    </message>
     <message>
         <source>Processing</source>
         <translation>Επεξεργασία</translation>
@@ -1083,6 +1075,34 @@ Exampe 2: ${gateway}:8080</source>
         <source>Renaming Failed: %3</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Skipping Checking Download Hash</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ignoring Download Because Hashes Do Not Match</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Expected &quot;%1&quot; but obtained &quot;%2&quot;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed To Remove</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Renaming file to: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed To Find &quot;bsdtar&quot; Executable</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Skipping Checking Version Info For Engine &quot;%1&quot;</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>basicdownloader</name>
