@@ -579,10 +579,6 @@ Per aggiungere più playlist, separale con uno spazio o una nuova riga</translat
         <source>Failed to parse json file from github</source>
         <translation>Impossibile analizzare il file json da Github</translation>
     </message>
-    <message>
-        <source>Renaming file to: </source>
-        <translation>Rinomina file in: </translation>
-    </message>
     <message>
         <source>Turkish (Turkey)</source>
         <translation>Turco (Turchia)</translation>
@@ -833,10 +829,6 @@ Per maggiori dettagli vedi la GNU (General Public License).</translation>
         <source>Failed To Find &quot;bsdtar.exe&quot; Executable</source>
         <translation>Impossibile trovare l&apos;eseguibile &quot;bsdtar.exe&quot;</translation>
     </message>
-    <message>
-        <source>Failed To Find &quot;tar&quot; Executable</source>
-        <translation>Impossibile trovare l&apos;eseguibile &quot;tar&quot;</translation>
-    </message>
     <message>
         <source>Running In Portable Mode</source>
         <translation>Esegui in modo portatile</translation>
@@ -1079,12 +1071,40 @@ Per maggiori dettagli vedi la GNU (General Public License).</translation>
     </message>
     <message>
         <source>Renaming &quot;%1&quot; to &quot;%2&quot;</source>
-        <translation>Rinoma di &quot;%1&quot; in &quot;%2&quot;</translation>
+        <translation>Rinomina di &quot;%1&quot; in &quot;%2&quot;</translation>
     </message>
     <message>
         <source>Renaming Failed: %3</source>
         <translation>Rinomina fallita: %3</translation>
     </message>
+    <message>
+        <source>Skipping Checking Download Hash</source>
+        <translation>Salta controllo hash download</translation>
+    </message>
+    <message>
+        <source>Ignoring Download Because Hashes Do Not Match</source>
+        <translation>Download saltato perché gli hash non corrispondono</translation>
+    </message>
+    <message>
+        <source>Expected &quot;%1&quot; but obtained &quot;%2&quot;</source>
+        <translation>Previsto &quot;%1&quot;, ottenuto &quot;%2&quot;</translation>
+    </message>
+    <message>
+        <source>Failed To Remove</source>
+        <translation>Impossibile effettuare la rimozione</translation>
+    </message>
+    <message>
+        <source>Renaming file to: %1</source>
+        <translation>Rinomina file in: %1</translation>
+    </message>
+    <message>
+        <source>Failed To Find &quot;bsdtar&quot; Executable</source>
+        <translation>Impossibile trovare l&apos;eseguibile &quot;bsdtar&quot;</translation>
+    </message>
+    <message>
+        <source>Skipping Checking Version Info For Engine &quot;%1&quot;</source>
+        <translation>Ignora controllo informazioni versione per il motore &quot;%1&quot;</translation>
+    </message>
 </context>
 <context>
     <name>basicdownloader</name>
