@@ -552,10 +552,6 @@ Exampe 2: ${gateway}:8080</source>
         <source>Failed to parse json file from github</source>
         <translation>Kan het json-bestand van github niet ontleden</translation>
     </message>
-    <message>
-        <source>Renaming file to: </source>
-        <translation>Hernoem bestand naar: </translation>
-    </message>
     <message>
         <source>Turkish (Turkey)</source>
         <translation>Turks(Turkije)</translation>
@@ -828,10 +824,6 @@ Exampe 2: ${gateway}:8080</source>
         <source>Failed To Find &quot;bsdtar.exe&quot; Executable</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Failed To Find &quot;tar&quot; Executable</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Running In Portable Mode</source>
         <translation type="unfinished"></translation>
@@ -1068,6 +1060,46 @@ Exampe 2: ${gateway}:8080</source>
         <source>Download Failed, Network Issue</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Ukrainian (Ukraine)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Renaming &quot;%1&quot; to &quot;%2&quot;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Renaming Failed: %3</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Skipping Checking Download Hash</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ignoring Download Because Hashes Do Not Match</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Expected &quot;%1&quot; but obtained &quot;%2&quot;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed To Remove</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Renaming file to: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed To Find &quot;bsdtar&quot; Executable</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Skipping Checking Version Info For Engine &quot;%1&quot;</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>basicdownloader</name>
