@@ -746,10 +746,6 @@ Exemplo 2: ${gateway}:8080</translation>
         <source>Failed To Find &quot;bsdtar.exe&quot; Executable</source>
         <translation>Falha ao encontrar o executável &quot;bsdtar.exe&quot;</translation>
     </message>
-    <message>
-        <source>Failed To Find &quot;tar&quot; Executable</source>
-        <translation>Falha ao encontrar o executável &quot;tar&quot;</translation>
-    </message>
     <message>
         <source>Download Failed</source>
         <translation>Falha no  download</translation>
@@ -786,10 +782,6 @@ Exemplo 2: ${gateway}:8080</translation>
         <source>Extracting archive: </source>
         <translation>Extraindo arquivo: </translation>
     </message>
-    <message>
-        <source>Renaming file to: </source>
-        <translation>Renomear arquivo para: </translation>
-    </message>
     <message>
         <source>Processing</source>
         <translation>Processamento</translation>
@@ -1070,6 +1062,46 @@ Exemplo 2: ${gateway}:8080</translation>
         <source>Download Failed, Network Issue</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Ukrainian (Ukraine)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Renaming &quot;%1&quot; to &quot;%2&quot;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Renaming Failed: %3</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Skipping Checking Download Hash</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ignoring Download Because Hashes Do Not Match</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Expected &quot;%1&quot; but obtained &quot;%2&quot;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed To Remove</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Renaming file to: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed To Find &quot;bsdtar&quot; Executable</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Skipping Checking Version Info For Engine &quot;%1&quot;</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>basicdownloader</name>
