@@ -746,10 +746,6 @@ Exampe 2: ${gateway}:8080</source>
         <source>Failed To Find &quot;bsdtar.exe&quot; Executable</source>
         <translation>Не вдалося знайти виконуваний файл &quot;bsdtar.exe&quot;</translation>
     </message>
-    <message>
-        <source>Failed To Find &quot;tar&quot; Executable</source>
-        <translation>Не вдалося знайти виконуваний файл &quot;tar&quot;</translation>
-    </message>
     <message>
         <source>Download Failed</source>
         <translation>Неможливо завантажити</translation>
@@ -786,10 +782,6 @@ Exampe 2: ${gateway}:8080</source>
         <source>Extracting archive: </source>
         <translation>Розпакування архіву: </translation>
     </message>
-    <message>
-        <source>Renaming file to: </source>
-        <translation>Перейменувати файл як: </translation>
-    </message>
     <message>
         <source>Processing</source>
         <translation>Обробка</translation>
@@ -1082,6 +1074,34 @@ Exampe 2: ${gateway}:8080</source>
         <source>Renaming Failed: %3</source>
         <translation>Не вдалося перейменувати: %3</translation>
     </message>
+    <message>
+        <source>Skipping Checking Download Hash</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ignoring Download Because Hashes Do Not Match</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Expected &quot;%1&quot; but obtained &quot;%2&quot;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed To Remove</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Renaming file to: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed To Find &quot;bsdtar&quot; Executable</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Skipping Checking Version Info For Engine &quot;%1&quot;</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>basicdownloader</name>
