@@ -736,10 +736,6 @@ Exampe 2: ${gateway}:8080</source>
         <source>Failed To Find &quot;bsdtar.exe&quot; Executable</source>
         <translation>无法找到&quot;bsdtar.exe&quot;可执行文件</translation>
     </message>
-    <message>
-        <source>Failed To Find &quot;tar&quot; Executable</source>
-        <translation>未能找到&quot;tar&quot;可执行文件</translation>
-    </message>
     <message>
         <source>Download Failed</source>
         <translation>下载失败</translation>
@@ -776,10 +772,6 @@ Exampe 2: ${gateway}:8080</source>
         <source>Extracting archive: </source>
         <translation>提取存档: </translation>
     </message>
-    <message>
-        <source>Renaming file to: </source>
-        <translation>将文件重命名为: </translation>
-    </message>
     <message>
         <source>Processing</source>
         <translation>处理中</translation>
@@ -1068,6 +1060,46 @@ Exampe 2: ${gateway}:8080</source>
         <source>Download Failed, Network Issue</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Ukrainian (Ukraine)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Renaming &quot;%1&quot; to &quot;%2&quot;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Renaming Failed: %3</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Skipping Checking Download Hash</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ignoring Download Because Hashes Do Not Match</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Expected &quot;%1&quot; but obtained &quot;%2&quot;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed To Remove</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Renaming file to: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed To Find &quot;bsdtar&quot; Executable</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Skipping Checking Version Info For Engine &quot;%1&quot;</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>basicdownloader</name>
